<?php

namespace App\Entity;

use App\Repository\MaterialTypeRepository;
use Doctrine\ORM\Mapping as ORM;
use Stringable;
use Symfony\Bridge\Doctrine\Validator\Constraints\UniqueEntity;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * A material type
 */
#[ORM\Entity(repositoryClass: MaterialTypeRepository::class)]
#[UniqueEntity(fields: ['name'], message: 'Il existe déjà un type de matériau avec ce nom')]
class MaterialType implements Stringable {
    use TBaseEntity;
    use TNamedEntity;

    /**
     * @var string|null The unit
     */
    #[ORM\Column(length: 5, nullable: true)]
    #[Assert\NotBlank(message: 'Veuillez saisir une unité', allowNull: true)]
    private ?string $unit = null;

    /**
     * @var string|null The “stack” name
     */
    #[ORM\Column(length: 50)]
    #[Assert\NotBlank(message: 'Veuillez saisir un nom de pile')]
    private ?string $stackName = null;
    /**
     * @var int|null The “stack” size
     */
    #[ORM\Column]
    #[Assert\Type(type: 'integer', message: 'La taille de pile doit être un nombre entier')]
    #[Assert\NotNull(message: 'Veuillez saisir une taille de pile')]
    #[Assert\Positive(message: 'La taille de pile doit être strictement positive')]
    private ?int $stackSize = null;

    /**
     * The unit
     *
     * @return string|null The unit
     */
    public function getUnit (): ?string {
        return $this->unit;
    }
    /**
     * Set the unit
     *
     * @param string|null $unit The unit
     *
     * @return $this
     */
    public function setUnit (?string $unit): self {
        $this->unit = $unit;
        return $this;
    }

    /**
     * The “stack” name
     *
     * @return string|null The “stack” name
     */
    public function getStackName (): ?string {
        return $this->stackName;
    }
    /**
     * Set the “stack” name
     *
     * @param string $stackName The “stack” name
     *
     * @return $this
     */
    public function setStackName (string $stackName): static {
        $this->stackName = $stackName;

        return $this;
    }

    /**
     * The “stack” size
     *
     * @return int|null The “stack” size
     */
    public function getStackSize (): ?int {
        return $this->stackSize;
    }
    /**
     * Set the “stack” size
     *
     * @param int $stackSize The “stack” size
     *
     * @return $this
     */
    public function setStackSize (int $stackSize): static {
        $this->stackSize = $stackSize;

        return $this;
    }
}
